<?php
namespace Teknisa\SM\Controller;

use Teknisa\SM\Controller\SMCrud;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DataSource\DataSet;
use Teknisa\SM\Service\Sm00012000MedicaoFaturamentoService;

class Sm00012000MedicaoFaturamentoController extends SMCrud {
    
    protected $medicaoService;
    
    public function __construct($crudService, $environment, Sm00012000MedicaoFaturamentoService $medicaoService) {
        parent::__construct($crudService, $environment);
        $this->medicaoService = $medicaoService;
    }

    /**
    * Faz o cálculo dos itens de acordo com a medida variável
    */
    public function recalcularItensMedicao(Request\Row $request, Response $response) {
        try {
            $row = $request->getRow();
            $nrmedicaofatura = $row["NRMEDICAOFATURA"];
            $nrseqcontrato   = $row["NRSEQCONTRATO"];
            
            $this->medicaoService->recalcularItensMedicao($nrmedicaofatura, $nrseqcontrato);
        }
        catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    /**
     * Executa a procedure "FCT_GERAR_PARCELAS_APURACAO".
     */
    public function gerarApuracaoFatura(Request\Row $request, Response $response) {
        try {
            $row = $request->getRow();
            $nrmedicaofatura = $row["NRMEDICAOFATURA"];
            $nrseqcontrato   = $row["NRSEQCONTRATO"];
            
            $this->medicaoService->gerarApuracaoFatura($nrmedicaofatura, $nrseqcontrato);
        }
        catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    /**
     * Executa a procedure "FCT_CANCELAR_MEDICAO".
     */
    public function cancelarMedicao(Request\Row $request, Response $response) {
        try {
            $row = $request->getRow();
            $nrmedicaofatura = $row["NRMEDICAOFATURA"];
            $nrseqcontrato   = $row["NRSEQCONTRATO"];
            
            $this->medicaoService->cancelarMedicao($nrmedicaofatura, $nrseqcontrato);
        }
        catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    /**
     * A função "validaFatura" valida se ja foi gerada parcela.
     */
    public function validaFatura(Request\Row $request, Response $response) {
        try {
            $row = $request->getRow();
            
            $nrmedicaofatura = $row["NRMEDICAOFATURA"];
            $nrseqcontrato   = $row["NRSEQCONTRATO"];

            $valida = $this->medicaoService->validaFatura($nrmedicaofatura, $nrseqcontrato);
            
            $response->addDataSet(new DataSet("VALIDA", array("QUANTIDADE" => $valida)));
        }
        catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    
    /**
    * Executa a procedure "FCT_CANCELAR_APURA_MEDICAO".
    */
    public function cancelarApuracaoMedicao(Request\Row $request, Response $response) {
        try {
            $row = $request->getRow();
            $nrmedicaofatura = $row["NRMEDICAOFATURA"];
            $nrseqcontrato   = $row["NRSEQCONTRATO"];
            
            $this->medicaoService->cancelarApuracaoMedicao($nrmedicaofatura, $nrseqcontrato);
        }
        catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    
    /**
    * Executa a procedure atualiza a medida variável de acordo com os dados do OM.
    */
    public function atualizarMedVariavelOM(Request\DataSet $request, Response $response) {
        try {
            $parcelas = $request->getDataSet()->getRows()[0];
            
            $this->medicaoService->atualizarMedVariavelOM($parcelas);
            $response->addDataSet(new DataSet("SUCCESS", array("SUCESSO" => true)));
        }
        catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    /**
    * Faz o cálculo das medições recebidas
    */
    public function calcularMultiplasMedicoes(Request\DataSet $request, Response $response) {
        try {
            foreach ($request->getDataSet()->getRows() as $row) {
                $nrmedicaofatura = $row["NRMEDICAOFATURA"];
                $nrseqcontrato   = $row["NRSEQCONTRATO"];
                
                $this->medicaoService->recalcularItensMedicao($nrmedicaofatura, $nrseqcontrato);
            }
        }
        catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function cancelarMedicoes(Request\Row $request, Response $response) {
        try {
            $row = $request->getRow();
            $medicoes        = $row["MEDICOES"];
            $dsjustificacanc = $row["DSJUSTIFICACANC"];
            
            $nrorg      = $this->environment->getNrOrg();
            $cdoperador = $this->environment->getCdOperador();
            
            $this->medicaoService->cancelarMedicoes($medicoes, $dsjustificacanc, $nrorg, $cdoperador);
        }
        catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    /*public function getItensMedVar(Request\Filter $request, Response $response) {
        try {
            $filter = $request->getFilterCriteria()->getConditions();
            $nrmedicaofatura = $filter[0]["value"];
            
            $nrorg = $this->environment->getNrOrg();
            
            $dataset = $this->medicaoService->getItensMedVar($nrmedicaofatura, $nrorg, null);
            $response->addDataSet(new DataSet("getItensMedVar", $dataset));
        }
        catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }*/
    
}

?>