<?php
namespace Teknisa\SM\Factory;

use Doctrine\ORM\EntityManager;

class Sm00005000ParametrizacoesServicesFactory {
    
    protected $connection;
    
    public function __construct(EntityManager $entityManager) {
        $this->connection = $entityManager->getConnection();
    }
    
    /**
    * A função "buscaNovoCodigo" busca os códigos para validação
    */
    
    public function buscaNovoCodigo($params){
        
        $sql = "SELECT NRSEQUENCIAL 
                  FROM NOVOCODIGO 
                 WHERE CDCONTADOR = :CDCONTADOR 
                   AND NRORG = :NRORG";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    /**
     * A função "atualizaNovoCodigo" atualiza o novo codigo do contrato ou da proposta
     */
    
    public function atualizaNovoCodigo($params){
        
        $sql = "UPDATE NOVOCODIGO
                   SET NRSEQUENCIAL = :NRSEQUENCIAL,
                       NRORGULTATU  = :NRORG,
                       CDOPERULTATU = :OPERADOR,
                       DTULTATU = SYSDATE
                 WHERE CDCONTADOR = :CDCONTADOR
                   AND NRORG = :NRORG";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    /**
     * A função "insereNovoCodigo" insere o novo codigo do contrato ou da proposta
     */
    
    public function insereNovoCodigo($params){
        
        $sql = "INSERT INTO NOVOCODIGO(
                    CDCONTADOR, NRSEQUENCIAL, NRORG, DTINCLUSAO, NRORGINCLUSAO,
                    CDOPERINCLUSAO, IDATIVO)
                VALUES(
                    :CDCONTADOR, :NRSEQUENCIAL, :NRORG, SYSDATE, :NRORG,
                    :OPERADOR, 'S')";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }

    // save da parametrização por perfil de acesso

    public function saveperfilacessoProposta($params){
        $sql = "
        INSERT INTO FCT_ALTPROPCONCPERF(NRALTPROPCONCPERF, NRPERFILACESSO,NRORG, NRORGINCLUSAO,
         CDOPERINCLUSAO, CDOPERULTATU, NRORGULTATU, DTINCLUSAO, DTULTATU, IDATIVO)
        VALUES (
        :NRALTCONTRAPROVPERF, :NRPERFILACESSO, :NRORG, :NRORGINCLUSAO,
         :CDOPERINCLUSAO, :CDOPERULTATU, :NRORGULTATU, :DTINCLUSAO, :DTULTATU, :IDATIVO) ";
        $std = $this->connection->prepare($sql);
        $std->execute($params);

    }
    public function saveperfilacessoContrato($params){
        $sql = "
        INSERT INTO FCT_ALTCONTRAPROVPERF(NRALTCONTRAPROVPERF, NRPERFILACESSO,NRORG, NRORGINCLUSAO,
         CDOPERINCLUSAO, CDOPERULTATU, NRORGULTATU, DTINCLUSAO, DTULTATU, IDATIVO)
        VALUES (
        :NRALTCONTRAPROVPERF, :NRPERFILACESSO, :NRORG, :NRORGINCLUSAO,
         :CDOPERINCLUSAO, :CDOPERULTATU, :NRORGULTATU, :DTINCLUSAO, :DTULTATU, :IDATIVO) ";
        $std = $this->connection->prepare($sql);
        $std->execute($params);

    }

    public function deleteperfilacessoContrato($params){
        $sql = "
        DELETE FROM FCT_ALTCONTRAPROVPERF WHERE NRPERFILACESSO = :NRPERFILACESSO";
        $std = $this->connection->prepare($sql);
        $std->execute($params);

    }
    public function deleteperfilacessoProposta($params){
        $sql = "
        DELETE FROM FCT_ALTPROPCONCPERF WHERE NRPERFILACESSO = :NRPERFILACESSO";
        $std = $this->connection->prepare($sql);
        $std->execute($params);

    }
    public function validarperfilacesso($params){
        $sql = "SELECT NRPERFILACESSO 
                FROM PERFACESSPARC 
                WHERE NRPARCNEGOCIO = :NRPARCNEGOCIO";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();

    }

    public function buscarperfilacessoContrato($params){
        $sql = "
        SELECT NRPERFILACESSO FROM FCT_ALTCONTRAPROVPERF WHERE NRORG = :NRORG";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    public function buscarperfilacessoProposta($params){
        $sql = "
        SELECT NRPERFILACESSO FROM FCT_ALTPROPCONCPERF WHERE NRORG = :NRORG";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    /**
     * Busca o id que define se o sistema possui ou não hierarquia de operadores
    **/
    public function getIdUtilizaHierarquiaOper(array $params){
        $sql = "SELECT IDUTILIZAHIEROPER
                FROM FCT_PARAMETROGERAL
                WHERE NRORG = :NRORG";
                
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
     /**
     * A função "validaPercentual" valida o percentual para inserção na página "índices Financeiros Padrões"
     */
    
    public function validaPercentual(array $params){
        $sql = "SELECT SUM(NRPERCENTINDICE) AS TOTPERCENT 
                FROM FCT_INDICESPADROES
                WHERE NRORG     = :NRORG
                  AND (CDINDICE <> :CDINDICE OR :CDINDICE IS NULL)";
                 
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    /**
     * valida se o Token do Certsign está preenchido
    **/
    public function validaTokenCertsign(array $params) {
        
        $sql = "SELECT DSTOKENCERTSIGN 
                  FROM FCT_PARAMETROGERAL
                 WHERE NRORG = :NRORG";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    /**
     * A função "validaSignatPadr" realiza a validação dos signatários padrões para evitar a inclusão repetida de um parceiro.
     */
    public function validaSignatCadastrados(array $params) {
        
        $sql = "SELECT COUNT (*) AS VALIDA
                  FROM FCT_SIGNATARIOSPADR
                 WHERE (((IDTPSIGNATARIO = 'SE') AND (NRPARCNEGOCIO = :NRPARCNEGOCIO))
                    OR (((IDTPSIGNATARIO <>'SE')) AND (IDTPSIGNATARIO = :IDTPSIGNATARIO)))
                   AND NRORG = :NRORG";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        $retorno = $std->fetchAll();
        return $retorno[0]["VALIDA"];
    }
     
    /**
     * insere os signatários padrões de cadastramento Automático
    **/
    public function insereSignatariosPadroesCadAuto(array $params) {
        
        $sql = "INSERT INTO FCT_SIGNATARIOSPADR (
                    NRSIGNATARIOSPADR,  NRPARCNEGOCIO,      IDTIPOASSINATURA,
                    IDTESTEMUNHA,       NRORDENACAO,        IDINSERCAOAUTO,
                    IDTPSIGNATARIO,     DSEMAILNOTSIGNENV,  DSEMAILNOTIFOUTROS,
                    NRORG,              DTINCLUSAO,         CDOPERINCLUSAO,
                    NRORGINCLUSAO,      IDATIVO
                )
                VALUES (
                    :NRSIGNATARIOSPADR, :NRPARCNEGOCIO,     :IDTIPOASSINATURA,
                    :IDTESTEMUNHA,      :NRORDENACAO,       :IDINSERCAOAUTO,
                    'SE',               :DSEMAILNOTSIGNENV, :DSEMAILNOTIFOUTROS,
                    :NRORG,             SYSDATE,            :OPERADOR,
                    :NRORG,             'S'
                )";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    
    /**
     * deleta os operadores de notificação de assinatura
    **/
    public function deletaOperadoresNotifica (array $params) {
        
        $sql = "DELETE FROM FCT_RELACOPERNOTIFASSELE
                 WHERE NRSIGNATARIOSPADR = :NRSIGNATARIOSPADR
                   AND NRORG = :NRORG";
                             
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    
    /**
     * insere os operadores de notificação de assinatura
    **/
    public function insereOperadoresNotifica (array $params) {
        
        $sql = "INSERT INTO FCT_RELACOPERNOTIFASSELE
                    (NRRELOPERNOTIFASSELE, NRSIGNATARIOSPADR, CDOPERADOR, NRORG, IDATIVO,            
                	 DTINCLUSAO, CDOPERINCLUSAO, NRORGINCLUSAO)
                VALUES 
                    (:NRRELOPERNOTIFASSELE, :NRSIGNATARIOSPADR, :CDOPERADOR, :NRORG, 'S',             
                	 SYSDATE, :OPERADOR, :NRORG)";
                             
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function getConfiguracoesEmail(array $params) {
        $sql = "SELECT DSHOSTEMAIL, DSPORTAEMAIL, DSUSUARIOEMAIL, DSSENHAEMAIL, IDSMTPSECURE
                  FROM FCT_PARAMETROGERAL
                 WHERE NRORG = :nrorg";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    public function pegarIdControleCarencia(array $params) {
        $sql = "SELECT IDBLOQCARENCMAXI FROM FCT_PARAMETROGERAL  WHERE NRORG = :NRORG";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    public function atualizarIdControleCarencia(array $params) {
        $sql = "UPDATE FCT_PARAMETROGERAL SET IDBLOQCARENCMAXI = :ID WHERE NRORG = :NRORG";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function pegarValidacaoCPF(array $params) {
        $sql = "SELECT IDVALIDACPFRF 
                  FROM FCT_PARAMETROGERAL
                 WHERE NRORG = :NRORG";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
}

?>